@@ -17,22 +17,18 @@ try:
 except ImportError:
     from markdown import etree
 
-
-def _is_numeric(x):
-    try:
-        float(x)
-        return True
-    except:
-        return False
-
-
 class STableProcessor(markdown.blockprocessors.BlockProcessor):
 
     def test(self, parent, block):
-        if not "\n" in block:
-            return False
-        if block[:2] != '!:':
+        print block[:6]
+        if block[:6] != 'STable':
             return False
+
+        print 'x' * 80
+        print block
+        print  "\n" in block
+        print block[:2]
+
         return True
 
     def run(self, parent, blocks):
